@@ -40,10 +40,10 @@
   Windows does not support MSG_DONTWAIT for send()/recv(). So we need to ensure
   that the socket is non-blocking at the start of every operation.
 */
-#define WIN_SET_NONBLOCKING(mysql) { \
+#define WIN_SET_NONBLOCKING(mysql) do { \
     my_bool old_mode; \
     if ((mysql)->net.pvio) ma_pvio_blocking((mysql)->net.pvio, FALSE, &old_mode); \
-  }
+  } while(0);
 #else
 #define WIN_SET_NONBLOCKING(mysql)
 #endif
@@ -140,7 +140,7 @@ my_ssl_async_check_result(int res, struct mysql_async_context *b, MARIADB_SSL *c
 {
   int ssl_err;
   b->events_to_wait_for= 0;
-  if (res >= 0)
+  if (res > 0)
     return 1;
   ssl_err= SSL_get_error(ssl, res);
   if (ssl_err == SSL_ERROR_WANT_READ)
